==> mx-menu-editor_19.8.tar.xz: mx-menu-editor-19.8/translations/mx-menu-editor_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Diàleg </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Categories </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Afegeix categoria </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Esborra Categoria </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Ordre: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Desa els canvis </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Surt del diàleg </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nom: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Comentari: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Icona: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Defineix icona </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Executa a terminal </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Notificador d&apos;arrencada </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Afegeix aplicació a mida </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>S&apos;ha produït un error</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>No es pot desar el fitxer </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Desa els canvis? </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Voleu desar la vostra edició? </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>MX Menu Editor</source>
        <translation>MX Menu Editor </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Advanced Editor</source>
        <translation>Editor Avançat </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Categories and applications</source>
        <translation>Categories i aplicacions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Add custom application</source>
        <translation>Afegeix aplicació a mida </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Run in terminal</source>
        <translation>Executa en terminal </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Hide</source>
        <translation>Amaga</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Notify startup</source>
        <translation>Notifica l&apos;engegada </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>Quick Editor</source>
        <translation>Editor Ràpid </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>Comment:</source>
        <translation>Comentari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Restore original item</source>
        <translation>Restaura l&apos;ítem original </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Command:</source>
        <translation>Ordre: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="190"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>Name:</source>
        <translation>Nom: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Icon</source>
        <translation>Icona </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Change icon</source>
        <translation>Canvia la icona </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Categories</source>
        <translation>Categories </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>Add</source>
        <translation>Afegeix </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Delete</source>
        <translation>Esborra </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Display help</source>
        <translation>Mostra l&apos;ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Save Changes</source>
        <translation>Desa els canvis </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Select executable file</source>
        <translation>Tria el fitxer executable </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Fitxers gràfics (*.png, *.jpg, *bmb, *xpm) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>Choose category</source>
        <translation>Trieu la categoria </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="726"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Could not save the file</source>
        <translation>No es pot desar el fitxer </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>About MX Menu Editor</source>
        <translation>Quant al MX Menu Editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programa per editar el menú Xfce </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="856"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>Save changes?</source>
        <translation>Desa els canvis? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>Do you want to save your edits?</source>
        <translation>Voleu desar la vostra edició? </translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Desa </translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Cal executar aquest programa com a usuari normal</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_19.9.tar.xz: mx-menu-editor-19.9/translations/mx-menu-editor_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Diàleg </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Categories </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Afegeix categoria </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Esborra Categoria </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Ordre: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Desa els canvis </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Surt del diàleg </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Seleccioneu...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nom: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Comentari: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Icona: </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Defineix icona </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Executa a terminal </translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Notificador d&apos;arrencada </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Afegeix aplicació a mida </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>S&apos;ha produït un error</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>No es pot desar el fitxer </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Desa els canvis? </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Voleu desar la vostra edició? </translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>MX Menu Editor</source>
        <translation>MX Menu Editor </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Editor Avançat </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Categories i aplicacions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Afegeix aplicació a mida </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Executa en terminal </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Amaga</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Notifica l&apos;engegada </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Editor Ràpid </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Comentari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Restaura l&apos;ítem original </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Ordre: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Seleccioneu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Nom: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Icona </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Change icon</source>
        <translation>Canvia la icona </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Categories </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Afegeix </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Esborra </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Mostra l&apos;ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Desa els canvis </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>Select executable file</source>
        <translation>Tria el fitxer executable </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Fitxers gràfics (*.png, *.jpg, *bmb, *xpm) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Choose category</source>
        <translation>Trieu la categoria </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="815"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="815"/>
        <source>Could not save the file</source>
        <translation>No es pot desar el fitxer </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>About MX Menu Editor</source>
        <translation>Quant al MX Menu Editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programa per editar el menú Xfce </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="901"/>
        <source>Save changes?</source>
        <translation>Desa els canvis? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="901"/>
        <source>Do you want to save your edits?</source>
        <translation>Voleu desar la vostra edició? </translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Cal executar aquest programa com a usuari normal</translation>
    </message>
</context>
</TS>
